/* nightlight.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __NIGHTLIGHT_H__
#define __NIGHTLIGHT_H__

#include <wingpanel-9.h>
#include <glib-object.h>
#include <glib.h>
#include <gmodule.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define GETTEXT_PACKAGE "nightlight-indicator"
#define LOCALEDIR "/usr/share/locale"

#define NIGHTLIGHT_TYPE_INDICATOR (nightlight_indicator_get_type ())
#define NIGHTLIGHT_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NIGHTLIGHT_TYPE_INDICATOR, NightlightIndicator))
#define NIGHTLIGHT_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NIGHTLIGHT_TYPE_INDICATOR, NightlightIndicatorClass))
#define NIGHTLIGHT_IS_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NIGHTLIGHT_TYPE_INDICATOR))
#define NIGHTLIGHT_IS_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NIGHTLIGHT_TYPE_INDICATOR))
#define NIGHTLIGHT_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NIGHTLIGHT_TYPE_INDICATOR, NightlightIndicatorClass))

typedef struct _NightlightIndicator NightlightIndicator;
typedef struct _NightlightIndicatorClass NightlightIndicatorClass;
typedef struct _NightlightIndicatorPrivate NightlightIndicatorPrivate;

#define NIGHT_LIGHT_TYPE_COLOR_INTERFACE (night_light_color_interface_get_type ())
#define NIGHT_LIGHT_COLOR_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NIGHT_LIGHT_TYPE_COLOR_INTERFACE, NightLightColorInterface))
#define NIGHT_LIGHT_IS_COLOR_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NIGHT_LIGHT_TYPE_COLOR_INTERFACE))
#define NIGHT_LIGHT_COLOR_INTERFACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), NIGHT_LIGHT_TYPE_COLOR_INTERFACE, NightLightColorInterfaceIface))

typedef struct _NightLightColorInterface NightLightColorInterface;
typedef struct _NightLightColorInterfaceIface NightLightColorInterfaceIface;

#define NIGHT_LIGHT_TYPE_COLOR_INTERFACE_PROXY (night_light_color_interface_proxy_get_type ())

#define NIGHT_LIGHT_TYPE_MANAGER (night_light_manager_get_type ())
#define NIGHT_LIGHT_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NIGHT_LIGHT_TYPE_MANAGER, NightLightManager))
#define NIGHT_LIGHT_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NIGHT_LIGHT_TYPE_MANAGER, NightLightManagerClass))
#define NIGHT_LIGHT_IS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NIGHT_LIGHT_TYPE_MANAGER))
#define NIGHT_LIGHT_IS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NIGHT_LIGHT_TYPE_MANAGER))
#define NIGHT_LIGHT_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NIGHT_LIGHT_TYPE_MANAGER, NightLightManagerClass))

typedef struct _NightLightManager NightLightManager;
typedef struct _NightLightManagerClass NightLightManagerClass;
typedef struct _NightLightManagerPrivate NightLightManagerPrivate;

#define NIGHTLIGHT_WIDGETS_TYPE_POPOVER_WIDGET (nightlight_widgets_popover_widget_get_type ())
#define NIGHTLIGHT_WIDGETS_POPOVER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NIGHTLIGHT_WIDGETS_TYPE_POPOVER_WIDGET, NightlightWidgetsPopoverWidget))
#define NIGHTLIGHT_WIDGETS_POPOVER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NIGHTLIGHT_WIDGETS_TYPE_POPOVER_WIDGET, NightlightWidgetsPopoverWidgetClass))
#define NIGHTLIGHT_WIDGETS_IS_POPOVER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NIGHTLIGHT_WIDGETS_TYPE_POPOVER_WIDGET))
#define NIGHTLIGHT_WIDGETS_IS_POPOVER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NIGHTLIGHT_WIDGETS_TYPE_POPOVER_WIDGET))
#define NIGHTLIGHT_WIDGETS_POPOVER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NIGHTLIGHT_WIDGETS_TYPE_POPOVER_WIDGET, NightlightWidgetsPopoverWidgetClass))

typedef struct _NightlightWidgetsPopoverWidget NightlightWidgetsPopoverWidget;
typedef struct _NightlightWidgetsPopoverWidgetClass NightlightWidgetsPopoverWidgetClass;
typedef struct _NightlightWidgetsPopoverWidgetPrivate NightlightWidgetsPopoverWidgetPrivate;

struct _NightlightIndicator {
	WingpanelIndicator parent_instance;
	NightlightIndicatorPrivate * priv;
};

struct _NightlightIndicatorClass {
	WingpanelIndicatorClass parent_class;
};

struct _NightLightColorInterfaceIface {
	GTypeInterface parent_iface;
	gboolean (*get_disabled_until_tomorrow) (NightLightColorInterface* self);
	void (*set_disabled_until_tomorrow) (NightLightColorInterface* self, gboolean value);
	gboolean (*get_night_light_active) (NightLightColorInterface* self);
};

struct _NightLightManager {
	GObject parent_instance;
	NightLightManagerPrivate * priv;
};

struct _NightLightManagerClass {
	GObjectClass parent_class;
};

struct _NightlightWidgetsPopoverWidget {
	GtkBox parent_instance;
	NightlightWidgetsPopoverWidgetPrivate * priv;
};

struct _NightlightWidgetsPopoverWidgetClass {
	GtkBoxClass parent_class;
};

VALA_EXTERN GType nightlight_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NightlightIndicator, g_object_unref)
VALA_EXTERN NightlightIndicator* nightlight_indicator_new (void);
VALA_EXTERN NightlightIndicator* nightlight_indicator_construct (GType object_type);
VALA_EXTERN void nightlight_indicator_set_nightlight_state (NightlightIndicator* self,
                                                gboolean value);
VALA_EXTERN WingpanelIndicator* get_indicator (GModule* module,
                                   WingpanelIndicatorManagerServerType server_type);
VALA_EXTERN GType night_light_color_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NightLightColorInterface, g_object_unref)
VALA_EXTERN GType night_light_color_interface_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint night_light_color_interface_register_object (void* object,
                                                   GDBusConnection* connection,
                                                   const gchar* path,
                                                   GError** error);
VALA_EXTERN gboolean night_light_color_interface_get_disabled_until_tomorrow (NightLightColorInterface* self);
VALA_EXTERN void night_light_color_interface_set_disabled_until_tomorrow (NightLightColorInterface* self,
                                                              gboolean value);
VALA_EXTERN gboolean night_light_color_interface_get_night_light_active (NightLightColorInterface* self);
VALA_EXTERN GType night_light_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NightLightManager, g_object_unref)
VALA_EXTERN NightLightManager* night_light_manager_get_instance (void);
VALA_EXTERN void night_light_manager_toggle_snooze (NightLightManager* self);
VALA_EXTERN gboolean night_light_manager_get_snoozed (NightLightManager* self);
VALA_EXTERN void night_light_manager_set_snoozed (NightLightManager* self,
                                      gboolean value);
VALA_EXTERN gboolean night_light_manager_get_active (NightLightManager* self);
VALA_EXTERN GType nightlight_widgets_popover_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NightlightWidgetsPopoverWidget, g_object_unref)
VALA_EXTERN NightlightWidgetsPopoverWidget* nightlight_widgets_popover_widget_new (void);
VALA_EXTERN NightlightWidgetsPopoverWidget* nightlight_widgets_popover_widget_construct (GType object_type);
VALA_EXTERN void nightlight_widgets_popover_widget_set_automatic_schedule (NightlightWidgetsPopoverWidget* self,
                                                               gboolean value);
VALA_EXTERN void nightlight_widgets_popover_widget_set_snoozed (NightlightWidgetsPopoverWidget* self,
                                                    gboolean value);
VALA_EXTERN void nightlight_widgets_popover_widget_set_temperature (NightlightWidgetsPopoverWidget* self,
                                                        gint value);

G_END_DECLS

#endif
